diff pidgin/gtkidle.c @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 75ffc646647f
children 66dff3dfdea6
line wrap: on
line diff
--- a/pidgin/gtkidle.c	Mon Mar 19 06:11:46 2007 +0000
+++ b/pidgin/gtkidle.c	Mon Mar 19 07:01:17 2007 +0000
@@ -1,7 +1,7 @@
 /*
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -52,7 +52,7 @@
  *
  * In Debian bug #271639, jwz says:
  *
  * Gaim should simply ask xscreensaver how long the user has been idle:
  *   % xscreensaver-command -time
  *   XScreenSaver 4.18: screen blanked since Tue Sep 14 14:10:45 2004
  *
@@ -117,7 +117,7 @@
 }
 #endif /* USE_SCREENSAVER || HAVE_IOKIT */
 
-static GaimIdleUiOps ui_ops =
+static PurpleIdleUiOps ui_ops =
 {
 #if defined(USE_SCREENSAVER) || defined(HAVE_IOKIT)
 	pidgin_get_time_idle
@@ -126,7 +126,7 @@
 #endif /* USE_SCREENSAVER || HAVE_IOKIT */
 };
 
-GaimIdleUiOps *
+PurpleIdleUiOps *
 pidgin_idle_get_ui_ops()
 {
 	return &ui_ops;
@@ -1,7 +1,7 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
@@ -52,7 +52,7 @@
  * In Debian bug #271639, jwz says:
  *
- * Gaim should simply ask xscreensaver how long the user has been idle:
+ * Purple should simply ask xscreensaver how long the user has been idle:
  *   % xscreensaver-command -time
  *   XScreenSaver 4.18: screen blanked since Tue Sep 14 14:10:45 2004